pulsator library

Classes

Pulsator
Pulsator widget that renders pulsating circles.
PulseGradientStyle
The style of the pulse gradient.
PulseIcon
A widget that displays an icon with a pulsing effect.
PulseStyle
The style of the pulse.

Enums

PulseFit
How the pulse should be scaled to fit the widget size.

Typedefs

OnCreatedListener = void Function(AnimationController controller)